pub enum QueryMsg {
IsWhitelisted {
vault: String,
},
IsValidating {
operator: String,
},
ListVaults {
limit: Option<u32>,
start_after: Option<String>,
},
ListVaultsByOperator {
operator: String,
limit: Option<u32>,
start_after: Option<String>,
},
WithdrawalLockPeriod {},
SlashingRequestId {
service: String,
operator: String,
},
SlashingRequest(SlashingRequestId),
SlashingLocked {
slashing_request_id: SlashingRequestId,
},
}Variants
IsWhitelisted
QueryMsg IsWhitelisted: returns true if the vault is whitelisted.
See ExecuteMsg::SetVault
IsValidating
QueryMsg IsValidating: returns true if the operator is validating services. See BVS Registry for more information.
ListVaults
QueryMsg ListVaults: returns a list of vaults.
You can provide limit and start_after to paginate the results.
The max limit is 100.
ListVaultsByOperator
QueryMsg ListVaultsByOperator: returns a list of vaults managed by given operator.
You can provide limit and start_after to paginate the results.
The max limit is 100.
WithdrawalLockPeriod
QueryMsg WithdrawalLockPeriod: returns the withdrawal lock period.
SlashingRequestId
SlashingRequest(SlashingRequestId)
SlashingLocked
Fields

slashing_request_id: SlashingRequestIdTrait Implementations
Sourceimpl<'de> Deserialize<'de> for QueryMsg
impl<'de> Deserialize<'de> for QueryMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryMsg
impl JsonSchema for QueryMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl QueryResponses for QueryMsg
impl QueryResponses for QueryMsg
fn response_schemas_impl() -> BTreeMap<String, RootSchema>
fn response_schemas() -> Result<BTreeMap<String, RootSchema>, IntegrityError>
Sourceimpl TestingContract<InstantiateMsg, ExecuteMsg, QueryMsg> for VaultRouterContract
impl TestingContract<InstantiateMsg, ExecuteMsg, QueryMsg> for VaultRouterContract
fn wrapper() -> Box<dyn Contract<Empty>>
fn default_init(app: &mut App, _env: &Env) -> InstantiateMsg
fn new(app: &mut App, env: &Env, msg: Option<InstantiateMsg>) -> Self
fn addr(&self) -> &Addr
fn store_code(app: &mut App) -> u64
fn instantiate(app: &mut App, code_id: u64, label: &str, msg: &IM) -> Addr
Sourcefn set_contract_addr(app: &mut App, label: &str, addr: &Addr)
fn set_contract_addr(app: &mut App, label: &str, addr: &Addr)
Set the contract address in the storage for the given label.
Using the storage system for easy orchestration of contract addresses for testing.
Sourcefn get_contract_addr(app: &App, label: &str) -> Addr
fn get_contract_addr(app: &App, label: &str) -> Addr
Get the contract address in the storage for the given label.
fn execute( &self, app: &mut App, sender: &Addr, msg: &EM, ) -> Result<AppResponse, Error>
fn execute_with_funds( &self, app: &mut App, sender: &Addr, msg: &EM, funds: Vec<Coin>, ) -> Result<AppResponse, Error>
fn query<T>(&self, app: &App, msg: &QM) -> Result<T, StdError>where
T: DeserializeOwned,
fn migrate( &self, app: &mut App, sender: &Addr, msg: &MM, ) -> Result<AppResponse, Error>
impl StructuralPartialEq for QueryMsg