pub struct RequestSlashingPayload {
pub operator: String,
pub bips: u16,
pub timestamp: Timestamp,
pub metadata: SlashingMetadata,
}Fields
operator: StringThe operator address to slash. (service, operator) must have active registration at the timestamp.
bips: u16The percentage of tokens to slash in basis points (1/100th of a percent). Max bips to slash is set by the service slashing parameters at the timestamp and the operator must have opted in.
timestamp: TimestampThe timestamp at which the slashing condition occurred.
metadata: SlashingMetadataAdditional contextual information about the slashing request.