pub struct RequestSlashingResponse(pub SlashingRequestId);Tuple Fields
0: SlashingRequestIdTrait Implementations
Sourceimpl Clone for RequestSlashingResponse
impl Clone for RequestSlashingResponse
Sourcefn clone(&self) -> RequestSlashingResponse
fn clone(&self) -> RequestSlashingResponse
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestSlashingResponse
impl Debug for RequestSlashingResponse
Sourceimpl<'de> Deserialize<'de> for RequestSlashingResponse
impl<'de> Deserialize<'de> for RequestSlashingResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Binary> for RequestSlashingResponse
impl From<Binary> for RequestSlashingResponse
Sourceimpl From<RequestSlashingResponse> for Binary
impl From<RequestSlashingResponse> for Binary
Sourcefn from(response: RequestSlashingResponse) -> Self
fn from(response: RequestSlashingResponse) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for RequestSlashingResponse
impl JsonSchema for RequestSlashingResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequestSlashingResponse
impl PartialEq for RequestSlashingResponse
Sourceimpl Serialize for RequestSlashingResponse
impl Serialize for RequestSlashingResponse
impl StructuralPartialEq for RequestSlashingResponse