Enum ExecuteMsg

pub enum ExecuteMsg {
    SetVault {
        vault: String,
        whitelisted: bool,
    },
    SetWithdrawalLockPeriod(Uint64),
    TransferOwnership {
        new_owner: String,
    },
    RequestSlashing(RequestSlashingPayload),
    LockSlashing(SlashingRequestId),
    CancelSlashing(SlashingRequestId),
    FinalizeSlashing(SlashingRequestId),
}

Variants



SetVault

ExecuteMsg SetVault the vault contract in the router and whitelist (true/false) it. Only the owner can call this message.

Fields

vault: String
whitelisted: bool


SetWithdrawalLockPeriod(Uint64)

ExecuteMsg SetWithdrawalLockPeriod the lock period for withdrawal. Only the owner can call this message.



TransferOwnership

ExecuteMsg TransferOwnership See bvs_library::ownership::transfer_ownership for more information on this field

Fields

new_owner: String


RequestSlashing(RequestSlashingPayload)

ExecuteMsg RequestSlashing initiates a slashing request against an active operator of the service (info.sender).

This ExecuteMsg allows a registered service to request a slash of an operator’s staked tokens as a penalty for violations or non-compliance. The slashing request must meet several criteria:

  • The service must be actively registered with the operator at the specified timestamp
  • The slashing amount (in bips) must not exceed the max_slashing_bips set by the service
  • The operator must have opted in to slashing at the specified timestamp
  • The timestamp must be within the allowable slashing window (not too old or in the future)
  • The service must not have another active slashing request against the same operator
  • The reason provided in metadata must not exceed the maximum allowed length

When successful, this creates a slashing request with an expiry time based on the resolution_window parameter and returns a unique slashing request ID.

Returns

On success, returns events with a data field set as RequestSlashingResponse containing the generated slashing request ID.



LockSlashing(SlashingRequestId)

ExecuteMsg LockSlashing initiates the movement of slashed collateral from vaults to the router which will later be finalized and handle according to the service slashing rules.



CancelSlashing(SlashingRequestId)

ExecuteMsg CancelSlashing cancels a resolved slashing request.

The service (slash initiator) should cancel the slashing process if the operator has resolved the issue. The definition of “resolved” is up to the service to define.



FinalizeSlashing(SlashingRequestId)

ExecuteMsg FinalizeSlashing moves the slashed collateral from the router to the destination specified in the slashing parameters that were agreed upon by the service and operator.

This is the final step in the slashing process and should only be called after the request has been locked, and the guardrail proposal has been voted on and passed.